@@ -59,6 +59,10 @@ class AudioResult(AbstractModel):
         :param LanguageResults: 该字段用于返回音频小语种检测的详细审核结果。具体结果内容请参见AudioResultDetailLanguageResult数据结构的细节描述。
 注意：此字段可能返回 null，表示取不到有效值。
         :type LanguageResults: list of AudioResultDetailLanguageResult
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.HitFlag = None
         self.Label = None
@@ -71,6 +75,7 @@ class AudioResult(AbstractModel):
         self.TextResults = None
         self.MoanResults = None
         self.LanguageResults = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -100,6 +105,7 @@ class AudioResult(AbstractModel):
                 obj = AudioResultDetailLanguageResult()
                 obj._deserialize(item)
                 self.LanguageResults.append(obj)
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -172,12 +178,17 @@ class AudioResultDetailMoanResult(AbstractModel):
         :type EndTime: float
         :param SubLabelCode: *内测中，敬请期待*
         :type SubLabelCode: str
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.Label = None
         self.Score = None
         self.StartTime = None
         self.EndTime = None
         self.SubLabelCode = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -186,6 +197,7 @@ class AudioResultDetailMoanResult(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.SubLabelCode = params.get("SubLabelCode")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -224,6 +236,10 @@ class AudioResultDetailTextResult(AbstractModel):
         :param LibType: 该字段用于返回自定义关键词对应的词库类型，取值为**1**（黑白库）和**2**（自定义关键词库），若未配置自定义关键词库,则默认值为1（黑白库匹配）。
 注意：此字段可能返回 null，表示取不到有效值。
         :type LibType: int
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.Label = None
         self.Keywords = None
@@ -232,6 +248,7 @@ class AudioResultDetailTextResult(AbstractModel):
         self.Score = None
         self.Suggestion = None
         self.LibType = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -242,6 +259,7 @@ class AudioResultDetailTextResult(AbstractModel):
         self.Score = params.get("Score")
         self.Suggestion = params.get("Suggestion")
         self.LibType = params.get("LibType")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -689,6 +707,10 @@ class ImageResult(AbstractModel):
         :param Extra: 该字段用于返回输入参数中的额外附加信息（Extra），如未配置则默认返回值为空。<br>备注：不同客户或Biztype下返回信息不同，如需配置该字段请提交工单咨询或联系售后专员处理。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Extra: str
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.HitFlag = None
         self.Label = None
@@ -697,6 +719,7 @@ class ImageResult(AbstractModel):
         self.Results = None
         self.Url = None
         self.Extra = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -712,6 +735,7 @@ class ImageResult(AbstractModel):
                 self.Results.append(obj)
         self.Url = params.get("Url")
         self.Extra = params.get("Extra")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1200,16 +1224,22 @@ class TaskLabel(AbstractModel):
         :param Score: 该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Score: int
+        :param SubLabel: 该字段用于返回当前标签（Lable）下的二级标签。
+注意：此字段可能返回null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.Label = None
         self.Suggestion = None
         self.Score = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
         self.Label = params.get("Label")
         self.Suggestion = params.get("Suggestion")
         self.Score = params.get("Score")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
